.. flask-peewee documentation master file, created by
   sphinx-quickstart on Tue Sep 20 13:19:30 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

flask-peewee
============

Welcome to the flask-peewee documentation!

provides a layer of integration between the `flask <http://flask.pocoo.org/>`_
web framework and the `peewee orm <http://peewee.rtfd.org/>`_.

Contents:

.. toctree::
   :maxdepth: 2
   :glob:

   installation
   getting-started
   database
   admin
   auth
   rest-api
   utils
   gevent

API in depth:

.. toctree::
    :maxdepth: 2
    :glob:

    api/

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
